==> openshift-model-4.11.2-sources.jar: annotations/io/fabric8/openshift/api/model/OpenIDClaimsFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface OpenIDClaimsFluent<A extends OpenIDClaimsFluent<A>> extends Fluent<A>{


    public A addToEmail(int index,String item);
    public A setToEmail(int index,String item);
    public A addToEmail(String... items);
    public A addAllToEmail(Collection<String> items);
    public A removeFromEmail(String... items);
    public A removeAllFromEmail(Collection<String> items);
    public List<String> getEmail();
    public String getEmail(int index);
    public String getFirstEmail();
    public String getLastEmail();
    public String getMatchingEmail(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingEmail(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withEmail(List<String> email);
    public A withEmail(String... email);
    public Boolean hasEmail();
    public A addNewEmail(String arg1);
    public A addNewEmail(StringBuilder arg1);
    public A addNewEmail(StringBuffer arg1);
    public A addToName(int index,String item);
    public A setToName(int index,String item);
    public A addToName(String... items);
    public A addAllToName(Collection<String> items);
    public A removeFromName(String... items);
    public A removeAllFromName(Collection<String> items);
    public List<String> getName();
    public String getName(int index);
    public String getFirstName();
    public String getLastName();
    public String getMatchingName(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingName(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withName(List<String> name);
    public A withName(String... name);
    public Boolean hasName();
    public A addNewName(String arg1);
    public A addNewName(StringBuilder arg1);
    public A addNewName(StringBuffer arg1);
    public A addToPreferredUsername(int index,String item);
    public A setToPreferredUsername(int index,String item);
    public A addToPreferredUsername(String... items);
    public A addAllToPreferredUsername(Collection<String> items);
    public A removeFromPreferredUsername(String... items);
    public A removeAllFromPreferredUsername(Collection<String> items);
    public List<String> getPreferredUsername();
    public String getPreferredUsername(int index);
    public String getFirstPreferredUsername();
    public String getLastPreferredUsername();
    public String getMatchingPreferredUsername(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingPreferredUsername(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withPreferredUsername(List<String> preferredUsername);
    public A withPreferredUsername(String... preferredUsername);
    public Boolean hasPreferredUsername();
    public A addNewPreferredUsername(String arg1);
    public A addNewPreferredUsername(StringBuilder arg1);
    public A addNewPreferredUsername(StringBuffer arg1);



}

==> openshift-model-5.0.1-sources.jar: annotations/io/fabric8/openshift/api/model/OpenIDClaimsFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface OpenIDClaimsFluent<A extends OpenIDClaimsFluent<A>> extends Fluent<A> {


    public A addToEmail(int index,String item);
    public A setToEmail(int index,String item);
    public A addToEmail(String... items);
    public A addAllToEmail(Collection<String> items);
    public A removeFromEmail(String... items);
    public A removeAllFromEmail(Collection<String> items);
    public List<String> getEmail();
    public String getEmail(int index);
    public String getFirstEmail();
    public String getLastEmail();
    public String getMatchingEmail(Predicate<String> predicate);
    public Boolean hasMatchingEmail(Predicate<String> predicate);
    public A withEmail(List<String> email);
    public A withEmail(String... email);
    public Boolean hasEmail();
    public A addNewEmail(String arg1);
    public A addNewEmail(StringBuilder arg1);
    public A addNewEmail(StringBuffer arg1);
    public A addToName(int index,String item);
    public A setToName(int index,String item);
    public A addToName(String... items);
    public A addAllToName(Collection<String> items);
    public A removeFromName(String... items);
    public A removeAllFromName(Collection<String> items);
    public List<String> getName();
    public String getName(int index);
    public String getFirstName();
    public String getLastName();
    public String getMatchingName(Predicate<String> predicate);
    public Boolean hasMatchingName(Predicate<String> predicate);
    public A withName(List<String> name);
    public A withName(String... name);
    public Boolean hasName();
    public A addNewName(String arg1);
    public A addNewName(StringBuilder arg1);
    public A addNewName(StringBuffer arg1);
    public A addToPreferredUsername(int index,String item);
    public A setToPreferredUsername(int index,String item);
    public A addToPreferredUsername(String... items);
    public A addAllToPreferredUsername(Collection<String> items);
    public A removeFromPreferredUsername(String... items);
    public A removeAllFromPreferredUsername(Collection<String> items);
    public List<String> getPreferredUsername();
    public String getPreferredUsername(int index);
    public String getFirstPreferredUsername();
    public String getLastPreferredUsername();
    public String getMatchingPreferredUsername(Predicate<String> predicate);
    public Boolean hasMatchingPreferredUsername(Predicate<String> predicate);
    public A withPreferredUsername(List<String> preferredUsername);
    public A withPreferredUsername(String... preferredUsername);
    public Boolean hasPreferredUsername();
    public A addNewPreferredUsername(String arg1);
    public A addNewPreferredUsername(StringBuilder arg1);
    public A addNewPreferredUsername(StringBuffer arg1);
}
